import base64
from typing import Dict, Optional, Any


class LambdaResponse(object):
    def __init__(
        self,
        status: int,
        response: Optional[Any],
        headers: Optional[Dict[str, str]],
    ):
        self.response = {"statusCode": status}
        if response:
            if (("Content-Type" in headers and
                    headers["Content-Type"] is not None and
                    not headers["Content-Type"].startswith("application/json")) or (
                    "Content-Encoding" in headers and
                    headers["Content-Encoding"] is not None and
                    headers["Content-Encoding"].startswith("gzip")
            )):
                self.response["body"] = base64.b64encode(response)
                headers["x-lambda-base64-body"] = "true"
            else:
                self.response["body"] = response
        if headers:
            self.response["headers"] = {}
            for header in headers:
                self.response["headers"][header] = headers[header]



import logging
from typing import Dict

from httpclient import HttpRequest
from httpmessagehandler import HttpMessageHandler
from ._KongRequest import KongRequest
from ._LambdaResponse import LambdaResponse

logger = logging.getLogger()


class KongLambdaMessageHandler(object):

    def __init__(
        self,
        http_message_handler: HttpMessageHandler,
    ) -> None:

        self.http_message_handler = http_message_handler

    def handle_messages(self, event: Dict) -> LambdaResponse:

        request = KongRequest(event)

        http_request = HttpRequest(
            url=request.path,
            method=request.method,
            query=request.args,
            headers=request.headers,
            body=request.data,
        )
        http_response = self.http_message_handler.handle_request(request=http_request)
        response = LambdaResponse(
            status=http_response.status_code,
            response=http_response.body,
            headers=http_response.headers,
        )
        return response.response
